<?php
if (!defined('ABSPATH')) {
    exit;
}

function bcb_register_settings() {

    $existing_settings = get_option('bcb_settings', false);
    
if (false === $existing_settings) {
        add_option('bcb_settings', array(
            'title_font_size' => 16,
            'title_font_weight' => 700,
            'title_color' => '#333333',
            'title_max_lines' => 2,
            'excerpt_font_size' => 14,
            'excerpt_font_weight' => 400,
            'excerpt_color' => '#666666',
            'excerpt_max_lines' => 3,
            'site_name_font_size' => 12,
            'site_name_font_weight' => 500,
            'site_name_color' => '#888888',
            'site_url_font_size' => 11,
            'site_url_font_weight' => 400,
            'site_url_color' => '#aaaaaa',
            'default_show_thumbnail' => true,
            'default_show_excerpt' => false,
            'default_show_site_info' => true,
            'default_thumbnail_position' => 'left',
            'default_border_style' => 'solid',
            'default_border_width' => 1,
            'default_border_color' => '#d5d5d5',
            'default_border_radius' => 5,
            'default_background_color' => '#ffffff',
            'default_width' => 100,
            'default_alignment' => 'center',
        ));
    }
    
    register_setting('bcb_options_group', 'bcb_settings', 'bcb_sanitize_options');
    
    add_settings_section(
        'bcb_general_section',
        __('ブログカード設定', 'blog-card-block'),
        'bcb_general_section_callback',
        'blog-card-block'
    );
}
add_action('admin_init', 'bcb_register_settings');

function bcb_sanitize_options($options) {
    if (!is_array($options)) {
        return array();
    }
    
    $sanitized = array();
    
    // Title settings
    $sanitized['title_font_size'] = intval($options['title_font_size'] ?? 16);
    $sanitized['title_font_weight'] = intval($options['title_font_weight'] ?? 700);
    $sanitized['title_color'] = sanitize_hex_color($options['title_color'] ?? '#333333');
    $sanitized['title_max_lines'] = intval($options['title_max_lines'] ?? 2);
    
    // Excerpt settings
    $sanitized['excerpt_font_size'] = intval($options['excerpt_font_size'] ?? 14);
    $sanitized['excerpt_font_weight'] = intval($options['excerpt_font_weight'] ?? 400);
    $sanitized['excerpt_color'] = sanitize_hex_color($options['excerpt_color'] ?? '#666666');
    $sanitized['excerpt_max_lines'] = intval($options['excerpt_max_lines'] ?? 3);
    
    // Site name settings
    $sanitized['site_name_font_size'] = intval($options['site_name_font_size'] ?? 12);
    $sanitized['site_name_font_weight'] = intval($options['site_name_font_weight'] ?? 500);
    $sanitized['site_name_color'] = sanitize_hex_color($options['site_name_color'] ?? '#888888');
    
    // Site URL settings
    $sanitized['site_url_font_size'] = intval($options['site_url_font_size'] ?? 11);
    $sanitized['site_url_font_weight'] = intval($options['site_url_font_weight'] ?? 400);
    $sanitized['site_url_color'] = sanitize_hex_color($options['site_url_color'] ?? '#aaaaaa');
    
    // Default settings
    $sanitized['default_show_thumbnail'] = isset($options['default_show_thumbnail']) ? true : false;
    $sanitized['default_show_excerpt'] = isset($options['default_show_excerpt']) ? true : false;
    $sanitized['default_show_site_info'] = isset($options['default_show_site_info']) ? true : false;
    
    $sanitized['default_thumbnail_position'] = sanitize_text_field($options['default_thumbnail_position'] ?? 'left');
    $sanitized['default_border_style'] = sanitize_text_field($options['default_border_style'] ?? 'solid');
    $sanitized['default_border_width'] = intval($options['default_border_width'] ?? 1);
    $sanitized['default_border_color'] = sanitize_hex_color($options['default_border_color'] ?? '#dddddd');
    $sanitized['default_border_radius'] = intval($options['default_border_radius'] ?? 8);
    $sanitized['default_background_color'] = sanitize_hex_color($options['default_background_color'] ?? '#ffffff');
    $sanitized['default_width'] = intval($options['default_width'] ?? 100);
    $sanitized['default_alignment'] = sanitize_text_field($options['default_alignment'] ?? 'left');
    
    return $sanitized;
}

function bcb_general_section_callback() {
    echo '<p>' . __('ブログカードブロックの表示設定を行います。これらの設定はすべてのブログカードに適用されます。', 'blog-card-block') . '</p>';
}

function bcb_add_admin_menu() {
    add_options_page(
        __('ブログカードブロック設定', 'blog-card-block'),
        __('ブログカードブロック', 'blog-card-block'),
        'manage_options',
        'blog-card-block',
        'bcb_options_page'
    );
}
add_action('admin_menu', 'bcb_add_admin_menu');

function bcb_options_page() {
    ?>
    <div class="wrap">
        
        <form method="post" action="options.php">
            <?php
            settings_fields('bcb_options_group');
            

            $options = get_option('bcb_settings', array());
            
            do_settings_sections('blog-card-block');
            ?>
            
            <h2><?php echo esc_html__('表示設定', 'blog-card-block'); ?></h2>
            <table class="form-table" role="presentation">
                <tr>
                    <th scope="row"><?php echo esc_html__('コンテンツ表示', 'blog-card-block'); ?></th>
                    <td>
                        <label for="bcb_default_show_thumbnail">
                            <input type="checkbox" id="bcb_default_show_thumbnail" name="bcb_settings[default_show_thumbnail]" 
                                <?php checked(isset($options['default_show_thumbnail']) ? $options['default_show_thumbnail'] : true); ?>>
                            <?php echo esc_html__('サムネイルを表示する', 'blog-card-block'); ?>
                        </label>
                        <p class="description"><?php echo esc_html__('リンク先のサムネイル画像を表示するかどうかを設定します。', 'blog-card-block'); ?></p>
                        
                        <br>
                        
                        <label for="bcb_default_show_excerpt">
                            <input type="checkbox" id="bcb_default_show_excerpt" name="bcb_settings[default_show_excerpt]" 
                                <?php checked(isset($options['default_show_excerpt']) ? $options['default_show_excerpt'] : true); ?>>
                            <?php echo esc_html__('抜粋を表示する', 'blog-card-block'); ?>
                        </label>
                        <p class="description"><?php echo esc_html__('リンク先の抜粋を表示するかどうかを設定します。', 'blog-card-block'); ?></p>
                        
                        <br>
                        
                        <label for="bcb_default_show_site_info">
                            <input type="checkbox" id="bcb_default_show_site_info" name="bcb_settings[default_show_site_info]" 
                                <?php checked(isset($options['default_show_site_info']) ? $options['default_show_site_info'] : true); ?>>
                            <?php echo esc_html__('サイト情報を表示する', 'blog-card-block'); ?>
                        </label>
                        <p class="description"><?php echo esc_html__('リンク先のサイト名とURLを表示するかどうかを設定します。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row"><?php echo esc_html__('サムネイル位置', 'blog-card-block'); ?></th>
                    <td>
                        <select name="bcb_settings[default_thumbnail_position]" id="bcb_default_thumbnail_position">
                            <option value="left" <?php selected($options['default_thumbnail_position'] ?? 'left', 'left'); ?>>
                                <?php echo esc_html__('左', 'blog-card-block'); ?>
                            </option>
                            <option value="right" <?php selected($options['default_thumbnail_position'] ?? 'left', 'right'); ?>>
                                <?php echo esc_html__('右', 'blog-card-block'); ?>
                            </option>
                        </select>
                        <p class="description"><?php echo esc_html__('サムネイル画像の表示位置を設定します。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row"><?php echo esc_html__('配置', 'blog-card-block'); ?></th>
                    <td>
                        <select name="bcb_settings[default_alignment]" id="bcb_default_alignment">
                            <option value="left" <?php selected($options['default_alignment'] ?? 'left', 'left'); ?>>
                                <?php echo esc_html__('左', 'blog-card-block'); ?>
                            </option>
                            <option value="center" <?php selected($options['default_alignment'] ?? 'left', 'center'); ?>>
                                <?php echo esc_html__('中央', 'blog-card-block'); ?>
                            </option>
                            <option value="right" <?php selected($options['default_alignment'] ?? 'left', 'right'); ?>>
                                <?php echo esc_html__('右', 'blog-card-block'); ?>
                            </option>
                        </select>
                        <p class="description"><?php echo esc_html__('ブログカードの配置を設定します。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row"><?php echo esc_html__('幅', 'blog-card-block'); ?></th>
                    <td>
                        <input type="number" id="bcb_default_width" name="bcb_settings[default_width]" value="<?php echo esc_attr($options['default_width'] ?? 100); ?>" min="50" max="100" step="1">
                        <span>%</span>
                        <p class="description"><?php echo esc_html__('ブログカードの幅を設定します。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
            </table>
            
            <h2><?php echo esc_html__('デザイン設定', 'blog-card-block'); ?></h2>
            <table class="form-table" role="presentation">
                <tr>
                    <th scope="row"><?php echo esc_html__('枠線設定', 'blog-card-block'); ?></th>
                    <td>
                        <select name="bcb_settings[default_border_style]" id="bcb_default_border_style">
                            <option value="none" <?php selected($options['default_border_style'] ?? 'solid', 'none'); ?>>
                                <?php echo esc_html__('なし', 'blog-card-block'); ?>
                            </option>
                            <option value="solid" <?php selected($options['default_border_style'] ?? 'solid', 'solid'); ?>>
                                <?php echo esc_html__('実線(solid)', 'blog-card-block'); ?>
                            </option>
                            <option value="dashed" <?php selected($options['default_border_style'] ?? 'solid', 'dashed'); ?>>
                                <?php echo esc_html__('破線(dashed)', 'blog-card-block'); ?>
                            </option>
                            <option value="dotted" <?php selected($options['default_border_style'] ?? 'solid', 'dotted'); ?>>
                                <?php echo esc_html__('点線(dotted)', 'blog-card-block'); ?>
                            </option>
                        </select>
                        <span style="margin-left: 10px; margin-right: 10px;"><?php echo esc_html__('太さ:', 'blog-card-block'); ?></span>
                        <input type="number" id="bcb_default_border_width" name="bcb_settings[default_border_width]" value="<?php echo esc_attr($options['default_border_width'] ?? 1); ?>" min="1" max="10" step="1">
                        <span>px</span>
                        <span style="margin-left: 10px; margin-right: 10px;"><?php echo esc_html__('色:', 'blog-card-block'); ?></span>
                        <input type="text" id="bcb_default_border_color" name="bcb_settings[default_border_color]" value="<?php echo esc_attr($options['default_border_color'] ?? '#dddddd'); ?>" class="bcb-color-picker">
                        <p class="description"><?php echo esc_html__('ブログカードの枠線スタイル、太さ、色を設定します。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row"><?php echo esc_html__('角丸', 'blog-card-block'); ?></th>
                    <td>
                        <input type="number" id="bcb_default_border_radius" name="bcb_settings[default_border_radius]" value="<?php echo esc_attr($options['default_border_radius'] ?? 8); ?>" min="0" max="50" step="1">
                        <span>px</span>
                        <p class="description"><?php echo esc_html__('ブログカードの角の丸みを設定します。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row"><?php echo esc_html__('背景色', 'blog-card-block'); ?></th>
                    <td>
                        <input type="text" id="bcb_default_background_color" name="bcb_settings[default_background_color]" value="<?php echo esc_attr($options['default_background_color'] ?? '#ffffff'); ?>" class="bcb-color-picker">
                        <p class="description"><?php echo esc_html__('ブログカードの背景色を設定します。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
            </table>
            
            <h2><?php echo esc_html__('テキスト設定', 'blog-card-block'); ?></h2>
            <table class="form-table" role="presentation">
                <tr>
                    <th scope="row"><?php echo esc_html__('タイトル', 'blog-card-block'); ?></th>
                    <td>
                        <div class="bcb-field-group">
                            <label for="bcb_title_font_size">
                                <?php echo esc_html__('サイズ:', 'blog-card-block'); ?>
                            </label>
                            <input type="number" id="bcb_title_font_size" name="bcb_settings[title_font_size]" value="<?php echo esc_attr($options['title_font_size'] ?? 16); ?>" min="10" max="32" step="1">
                            <span>px</span>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_title_font_weight">
                                <?php echo esc_html__('太さ:', 'blog-card-block'); ?>
                            </label>
                            <select name="bcb_settings[title_font_weight]" id="bcb_title_font_weight">
                                <option value="400" <?php selected($options['title_font_weight'] ?? 700, 400); ?>>
                                    <?php echo esc_html__('通常', 'blog-card-block'); ?>
                                </option>
                                <option value="500" <?php selected($options['title_font_weight'] ?? 700, 500); ?>>
                                    <?php echo esc_html__('やや太い', 'blog-card-block'); ?>
                                </option>
                                <option value="700" <?php selected($options['title_font_weight'] ?? 700, 700); ?>>
                                    <?php echo esc_html__('太字', 'blog-card-block'); ?>
                                </option>
                            </select>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_title_color">
                                <?php echo esc_html__('色:', 'blog-card-block'); ?>
                            </label>
                            <input type="text" id="bcb_title_color" name="bcb_settings[title_color]" value="<?php echo esc_attr($options['title_color'] ?? '#333333'); ?>" class="bcb-color-picker">
                        </div>
                        
                        <div class="bcb-field-group" style="margin-top: 10px;">
                            <label for="bcb_title_max_lines">
                                <?php echo esc_html__('最大行数:', 'blog-card-block'); ?>
                            </label>
                            <input type="number" id="bcb_title_max_lines" name="bcb_settings[title_max_lines]" value="<?php echo esc_attr($options['title_max_lines'] ?? 2); ?>" min="1" max="10" step="1">
                            <span><?php echo esc_html__('行', 'blog-card-block'); ?></span>
                        </div>
                        <p class="description"><?php echo esc_html__('タイトルの表示設定を行います。最大行数を超えた場合は省略されます。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row"><?php echo esc_html__('抜粋', 'blog-card-block'); ?></th>
                    <td>
                        <div class="bcb-field-group">
                            <label for="bcb_excerpt_font_size">
                                <?php echo esc_html__('サイズ:', 'blog-card-block'); ?>
                            </label>
                            <input type="number" id="bcb_excerpt_font_size" name="bcb_settings[excerpt_font_size]" value="<?php echo esc_attr($options['excerpt_font_size'] ?? 14); ?>" min="10" max="24" step="1">
                            <span>px</span>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_excerpt_font_weight">
                                <?php echo esc_html__('太さ:', 'blog-card-block'); ?>
                            </label>
                            <select name="bcb_settings[excerpt_font_weight]" id="bcb_excerpt_font_weight">
                                <option value="400" <?php selected($options['excerpt_font_weight'] ?? 400, 400); ?>>
                                    <?php echo esc_html__('通常', 'blog-card-block'); ?>
                                </option>
                                <option value="500" <?php selected($options['excerpt_font_weight'] ?? 400, 500); ?>>
                                    <?php echo esc_html__('やや太い', 'blog-card-block'); ?>
                                </option>
                                <option value="700" <?php selected($options['excerpt_font_weight'] ?? 400, 700); ?>>
                                    <?php echo esc_html__('太字', 'blog-card-block'); ?>
                                </option>
                            </select>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_excerpt_color">
                                <?php echo esc_html__('色:', 'blog-card-block'); ?>
                            </label>
                            <input type="text" id="bcb_excerpt_color" name="bcb_settings[excerpt_color]" value="<?php echo esc_attr($options['excerpt_color'] ?? '#666666'); ?>" class="bcb-color-picker">
                        </div>
                        
                        <div class="bcb-field-group" style="margin-top: 10px;">
                            <label for="bcb_excerpt_max_lines">
                                <?php echo esc_html__('最大行数:', 'blog-card-block'); ?>
                            </label>
                            <input type="number" id="bcb_excerpt_max_lines" name="bcb_settings[excerpt_max_lines]" value="<?php echo esc_attr($options['excerpt_max_lines'] ?? 3); ?>" min="1" max="10" step="1">
                            <span><?php echo esc_html__('行', 'blog-card-block'); ?></span>
                        </div>
                        <p class="description"><?php echo esc_html__('抜粋の表示設定を行います。最大行数を超えた場合は省略されます。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row"><?php echo esc_html__('サイト情報', 'blog-card-block'); ?></th>
                    <td>
                        <h4 style="margin: 0 0 10px;"><?php echo esc_html__('サイト名', 'blog-card-block'); ?></h4>
                        <div class="bcb-field-group">
                            <label for="bcb_site_name_font_size">
                                <?php echo esc_html__('サイズ:', 'blog-card-block'); ?>
                            </label>
                            <input type="number" id="bcb_site_name_font_size" name="bcb_settings[site_name_font_size]" value="<?php echo esc_attr($options['site_name_font_size'] ?? 12); ?>" min="8" max="18" step="1">
                            <span>px</span>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_site_name_font_weight">
                                <?php echo esc_html__('太さ:', 'blog-card-block'); ?>
                            </label>
                            <select name="bcb_settings[site_name_font_weight]" id="bcb_site_name_font_weight">
                                <option value="400" <?php selected($options['site_name_font_weight'] ?? 500, 400); ?>>
                                    <?php echo esc_html__('通常', 'blog-card-block'); ?>
                                </option>
                                <option value="500" <?php selected($options['site_name_font_weight'] ?? 500, 500); ?>>
                                    <?php echo esc_html__('やや太い', 'blog-card-block'); ?>
                                </option>
                                <option value="700" <?php selected($options['site_name_font_weight'] ?? 500, 700); ?>>
                                    <?php echo esc_html__('太字', 'blog-card-block'); ?>
                                </option>
                            </select>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_site_name_color">
                                <?php echo esc_html__('色:', 'blog-card-block'); ?>
                            </label>
                            <input type="text" id="bcb_site_name_color" name="bcb_settings[site_name_color]" value="<?php echo esc_attr($options['site_name_color'] ?? '#888888'); ?>" class="bcb-color-picker">
                        </div>
                        
                        <h4 style="margin: 15px 0 10px;"><?php echo esc_html__('サイトURL', 'blog-card-block'); ?></h4>
                        <div class="bcb-field-group">
                            <label for="bcb_site_url_font_size">
                                <?php echo esc_html__('サイズ:', 'blog-card-block'); ?>
                            </label>
                            <input type="number" id="bcb_site_url_font_size" name="bcb_settings[site_url_font_size]" value="<?php echo esc_attr($options['site_url_font_size'] ?? 11); ?>" min="8" max="16" step="1">
                            <span>px</span>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_site_url_font_weight">
                                <?php echo esc_html__('太さ:', 'blog-card-block'); ?>
                            </label>
                            <select name="bcb_settings[site_url_font_weight]" id="bcb_site_url_font_weight">
                                <option value="400" <?php selected($options['site_url_font_weight'] ?? 400, 400); ?>>
                                    <?php echo esc_html__('通常', 'blog-card-block'); ?>
                                </option>
                                <option value="500" <?php selected($options['site_url_font_weight'] ?? 400, 500); ?>>
                                    <?php echo esc_html__('やや太い', 'blog-card-block'); ?>
                                </option>
                                <option value="700" <?php selected($options['site_url_font_weight'] ?? 400, 700); ?>>
                                    <?php echo esc_html__('太字', 'blog-card-block'); ?>
                                </option>
                            </select>
                            
                            <span style="margin-left: 20px;"></span>
                            
                            <label for="bcb_site_url_color">
                                <?php echo esc_html__('色:', 'blog-card-block'); ?>
                            </label>
                            <input type="text" id="bcb_site_url_color" name="bcb_settings[site_url_color]" value="<?php echo esc_attr($options['site_url_color'] ?? '#aaaaaa'); ?>" class="bcb-color-picker">
                        </div>
                        <p class="description"><?php echo esc_html__('サイト情報の表示設定を行います。', 'blog-card-block'); ?></p>
                    </td>
                </tr>
            </table>
            
            <?php submit_button(); ?>
        </form>
        
        <div class="bcb-help-section">
            <h2><?php echo esc_html__('ブログカードの使い方', 'blog-card-block'); ?></h2>
            <div class="bcb-help-content">
                <h3><?php echo esc_html__('投稿編集画面でのブログカードの追加方法', 'blog-card-block'); ?></h3>
                <ol>
                    <li><?php echo esc_html__('投稿編集画面でブロックを追加する「+」ボタンをクリックします。', 'blog-card-block'); ?></li>
                    <li><?php echo esc_html__('「ブログカード」ブロックを検索して選択します。', 'blog-card-block'); ?></li>
                    <li><?php echo esc_html__('表示されたフィールドにリンクしたいURLを入力し、「取得」ボタンをクリックします。', 'blog-card-block'); ?></li>
                    <li><?php echo esc_html__('リンク先の情報が取得され、簡易的な表示に変わります。', 'blog-card-block'); ?></li>
                    <li><?php echo esc_html__('URLを変更したい場合は、「URLを変更」ボタンをクリックします。', 'blog-card-block'); ?></li>
                </ol>
                
                <h3><?php echo esc_html__('ブログカードの表示について', 'blog-card-block'); ?></h3>
                <p><?php echo esc_html__('ブログカードの表示は、このページで設定した内容に基づいて一括で適用されます。', 'blog-card-block'); ?></p>
                <p><?php echo esc_html__('投稿編集画面では簡易的な表示になりますが、実際の表示は下記の要素を含む完全なブログカードになります。設定後のデザインを確認したい場合は投稿内で下書き保存しプレビューで確認してください。', 'blog-card-block'); ?></p>
                <ul>
                    <li><?php echo esc_html__('リンク先のタイトル', 'blog-card-block'); ?></li>
                    <li><?php echo esc_html__('リンク先の抜粋（設定で表示を選択した場合）', 'blog-card-block'); ?></li>
                    <li><?php echo esc_html__('リンク先のサムネイル画像（設定で表示を選択した場合）', 'blog-card-block'); ?></li>
                    <li><?php echo esc_html__('リンク先のサイト情報（設定で表示を選択した場合）', 'blog-card-block'); ?></li>
                </ul>
                
                <h3><?php echo esc_html__('表示の更新について', 'blog-card-block'); ?></h3>
                <p><?php echo esc_html__('この設定ページで行った変更は、すべてのブログカードブロックに即時反映されます。', 'blog-card-block'); ?></p>
                <p><?php echo esc_html__('リンク先の情報（タイトル、抜粋、サムネイル）は24時間キャッシュされます。リンク先の内容が変更された場合、最大24時間後に更新されます。', 'blog-card-block'); ?></p>
                
                <h3><?php echo esc_html__('レスポンシブ表示について', 'blog-card-block'); ?></h3>
                <p><?php echo esc_html__('ブログカードはすべての画面サイズで常に横一列で表示されます。', 'blog-card-block'); ?></p>
            </div>
        </div>
    </div>
    
    <style>
        .bcb-field-group {
            display: flex;
            align-items: center;
        }
        
        .bcb-field-group label {
            margin-right: 5px;
        }
        
        .bcb-field-group input,
        .bcb-field-group select {
            margin-right: 5px;
        }
        
        .bcb-help-section {
            margin-top: 30px;
            background: #fff;
            padding: 20px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        
        .bcb-help-content {
            margin-top: 15px;
        }
        
        .bcb-help-content h3 {
            font-size: 16px;
            margin-bottom: 10px;
        }
        
        .bcb-help-content ol,
        .bcb-help-content ul {
            margin-left: 20px;
        }
        
        .bcb-help-content li {
            margin-bottom: 8px;
        }
    </style>
    
    <script>
        jQuery(document).ready(function($) {
            $('.bcb-color-picker').wpColorPicker();
        });
    </script>
    <?php
}

function bcb_admin_enqueue_scripts($hook) {
    if ('settings_page_blog-card-block' !== $hook) {
        return;
    }
    
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_script('wp-color-picker');
}
add_action('admin_enqueue_scripts', 'bcb_admin_enqueue_scripts');